@@ -3,9 +3,11 @@ Main interface for personalize-runtime service type definitions.
 
 Usage::
 
-    from mypy_boto3.personalize_runtime.type_defs import PredictedItemTypeDef
+    ```python
+    from mypy_boto3_personalize_runtime.type_defs import PredictedItemTypeDef
 
     data: PredictedItemTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
